/*-----------------------------------------------------------------------------
 * Name:    Buttons_STM32F3-Discovery.c
 * Purpose: Buttons interface for STM32F3-Discovery board
 * Rev.:    1.1.0
 *----------------------------------------------------------------------------*/

/* Copyright (c) 2013 - 2017 ARM LIMITED

   All rights reserved.
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions are met:
   - Redistributions of source code must retain the above copyright
     notice, this list of conditions and the following disclaimer.
   - Redistributions in binary form must reproduce the above copyright
     notice, this list of conditions and the following disclaimer in the
     documentation and/or other materials provided with the distribution.
   - Neither the name of ARM nor the names of its contributors may be used
     to endorse or promote products derived from this software without
     specific prior written permission.
   *
   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
   AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
   ARE DISCLAIMED. IN NO EVENT SHALL COPYRIGHT HOLDERS AND CONTRIBUTORS BE
   LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
   CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
   SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
   INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
   CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE.
   ---------------------------------------------------------------------------*/

/* Using the BSP Button driver for STM32 CubeMX targets
 
- In the CubeMX Pinout tab configure the pins connected to Buttons as GPIO_Input. 
- Select "Enter User Label" from the context menu of the pin
- Name the buttons B1 through B4 as available. 

This driver will pick up the names automatically after you generated code.
 
*/

#include "Board_Buttons.h"              // ::Board Support:Buttons

#include "stm32f3xx_hal.h"              // Device HAL

typedef struct {
  GPIO_TypeDef *port;
  uint16_t      pin;
  GPIO_PinState active_state;
  uint8_t       reserved;
} PIN_CONFIG_t;

/* ------------------------------- Configuration ---------------------------- */               

static const PIN_CONFIG_t PIN_CONFIG[] = {
#ifdef B1_Pin
    { B1_GPIO_Port, B1_Pin, GPIO_PIN_SET, 0U },
#endif	
#ifdef B2_Pin
    { B2_GPIO_Port, B2_Pin, GPIO_PIN_SET, 0U },
#endif	
#ifdef B3_Pin
    { B3_GPIO_Port, B3_Pin, GPIO_PIN_SET, 0U },
#endif	
#ifdef B4_Pin
    { B4_GPIO_Port, B4_Pin, GPIO_PIN_SET, 0U }
#endif			
};
	
	
#define BUTTON_NUM (sizeof(PIN_CONFIG)/sizeof(PIN_CONFIG_t))
/* -------------------------------------------------------------------------- */

/**
  \fn          int32_t Buttons_Initialize (void)
  \brief       Initialize I/O interface for buttons
  \returns
   - \b  0: function succeeded
   - \b -1: function failed
*/
int32_t Buttons_Initialize (void) {

  // All initialization code is generated by CubeMX
  return 0;
}

/**
  \fn          int32_t Buttons_Uninitialize (void)
  \brief       De-initialize I/O interface for buttons
  \returns
   - \b  0: function succeeded
   - \b -1: function failed
*/
int32_t Buttons_Uninitialize (void) {

  // All de-initialization code is generated by CubeMX
  return 0;
}

/**
  \fn          uint32_t Buttons_GetState (void)
  \brief       Get buttons state
  \returns     Buttons state
*/
uint32_t Buttons_GetState (void) {
  uint32_t val;
  uint8_t  i;

  val = 0U;
  for (i = 0U; i < BUTTON_NUM; i++) {
    if (HAL_GPIO_ReadPin(PIN_CONFIG[i].port, PIN_CONFIG[i].pin) == PIN_CONFIG[i].active_state) {
      val |= 1UL << i;
    }
  }

  return val;
}

/**
  \fn          uint32_t Buttons_GetCount (void)
  \brief       Get number of available buttons
  \return      Number of available buttons
*/
uint32_t Buttons_GetCount (void) {
  return BUTTON_NUM;
}

